@@ -1,8 +1,8 @@
 /*                                                                -*- C -*-
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2016 The PHP Group                                |
+   | Copyright (c) 1997-2018 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -18,7 +18,7 @@
 
 /* $Id$ */
 
-#define CONFIGURE_COMMAND " './configure'  '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--with-regex=system' '--without-mysql' '--without-iconv' '--without-pear' '--without-sqlite3' '--disable-posix' '--disable-opcache' '--disable-pdo' '--disable-json' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--with-libxml-dir=/usr/pkg' '--enable-ipv6' '--with-openssl=/usr' '--without-readline' '--prefix=/usr/pkg' '--build=x86_64--netbsd' '--host=x86_64--netbsd' '--mandir=/usr/pkg/man' 'build_alias=x86_64--netbsd' 'host_alias=x86_64--netbsd' 'CC=gcc' 'CFLAGS=-O2 '-D_FORTIFY_SOURCE=2' '-pthread' '-I/usr/pkg/include' '-I/usr/include'' 'LDFLAGS=-L/usr/pkg/lib '-Wl,-R/usr/pkg/lib' '-L/usr/lib' '-Wl,-R/usr/lib' '-pthread'' 'LIBS=' 'CPPFLAGS=-I/usr/pkg/include '-I/usr/include'' 'CXX=c++' 'CXXFLAGS=-O2 '-D_FORTIFY_SOURCE=2' '-pthread' '-I/usr/pkg/include' '-I/usr/include'' 'CXXCPP=cpp'"
+#define CONFIGURE_COMMAND " './configure'  '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--disable-posix' '--disable-opcache' '--disable-pdo' '--disable-json' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--with-libxml-dir=/usr/pkg' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=x86_64--netbsd' '--host=x86_64--netbsd' '--mandir=/usr/pkg/man' 'build_alias=x86_64--netbsd' 'host_alias=x86_64--netbsd' 'LIBS=' 'CXXCPP=cpp'"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
@@ -44,9 +44,9 @@
 #define PHP_MSQL_INCLUDE	""
 #define PHP_MSQL_LFLAGS		""
 #define PHP_MSQL_LIBS		""
-#define PHP_MYSQL_INCLUDE	""
-#define PHP_MYSQL_LIBS		""
-#define PHP_MYSQL_TYPE		""
+#define PHP_MYSQL_INCLUDE	"@MYSQL_INCLUDE@"
+#define PHP_MYSQL_LIBS		"@MYSQL_LIBS@"
+#define PHP_MYSQL_TYPE		"@MYSQL_MODULE_TYPE@"
 #define PHP_ODBC_INCLUDE	""
 #define PHP_ODBC_LFLAGS		""
 #define PHP_ODBC_LIBS		""
@@ -77,7 +77,7 @@
 #define PHP_BIRDSTEP_LIBS        ""
 #define PEAR_INSTALLDIR         ""
 #define PHP_INCLUDE_PATH	".:"
-#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/20140828"
+#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/20160303"
 #define PHP_PREFIX              "/usr/pkg"
 #define PHP_BINDIR              "/usr/pkg/bin"
 #define PHP_SBINDIR             "/usr/pkg/sbin"
